# Prodigi Photobook Maker SDK

[Prodigi](https://www.prodigi.com/) offers white label print on demand portals so that you can sell to your users under your brand. 

This SDK is compatible with the Prodigi [Photobook Maker](https://photobook.prodigi.com). Get your own branded instance at [Prodigi Apps Dashboard](https://dashboard.prodigi.com/apps).

With the Photobook Maker SDK, you can integrate your Photobook maker app into your own website, launching it with pre-configured data, such as images, at run-time.

## Table of Contents
- [Demo and examples](#demo-and-examples)
- [Installation](#installation)
- [Usage](#usage)
- [API](#api)

## Demo and examples

For a list of common use-cases and a demo sandbox, visit: [https://sdk.prodigi.com/photobook-maker](https://sdk.prodigi.com/photobook-maker)


## Installation

Install using NPM:

```
npm install @kite-tech/photobook-sdk
```

## Usage

Import the package:
```js
import { KitePhotobook } from '@kite-tech/photobook-sdk';
```
Launch your Photobook Maker app using the `launchPhotobook` function and pass in your desired configuration:
```js
const photobookMakerConfig = {
    baseUrl: 'https://photobook.prodigi.com/prodigi',
    images: []
};

KitePhotobook.launchPhotobook(photobookMakerConfig);
```

## API

| Property           | Type                                            | Required | Description                                                                                                                    |
|--------------------|-------------------------------------------------|----------|--------------------------------------------------------------------------------------------------------------------------------|
| baseUrl            | string                                          | YES      | The complete URL of your Photobook Maker                                                                                       |
| addNewImagesToBook | boolean                                         | NO       | If true, any images passed in are automatically added to the Photobook. Default is false                                       |
| bookSpineText      | string                                          | NO       | Optional text to print on the spine of the Photobook                                                                                 |
| clearBook          | boolean                                         | NO       | Clear the Photobook and image library on launch. Default is false                                                              |
| config             | <pre>{<br>  startInNewTab: boolean<br>}</pre>   | NO       | If true, the app opens in a new tab/window. Default is false                                                                   |
| checkoutFields     | [_CheckoutFieldsObject_](#CheckoutFieldsObject) | NO       | Populate the user's details on the checkout                                                                                           |
| images             | [_ImagesArray_](#ImagesArray)                   | YES      | Pass in images to use in the Photobook                                                                                            |
| variantTemplateId  | string                                          | NO       | Launch into a specific Photobook variant. Template IDs can be found inside the Prodigi apps dashboard.                         |


<br>


### CheckoutFieldsObject

| Property        | Type                                                                                                                                                                                                                                            | Required | Description                                                            |
|-----------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------|------------------------------------------------------------------------|
| shippingAddress | <pre> {<br>   recipient_first_name: string,<br>   recipient_last_name: string,<br>   address_line_1: string,<br>   address_line_2: string,<br>   city: string,<br>   county_state: string,<br>   postcode: string,<br>   country: string,<br> } | NO       | Populates the user's shipping address at the checkout. All values are optional |
| customerEmail   | string                                                                                                                                                                                                                                          | NO       | Sets the user's email address when they reach the checkout                   |
| termsOfService  | boolean                                                                                                                                                                                                                                         | NO       | Sets whether to automatically agree to terms of service on checkout           |


<br>


### ImagesArray

An array of objects having the following properties:

| Property     | Type                                                | Required | Description                                                                                                                                                                                                                                                                 |
|--------------|-----------------------------------------------------|----------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| dimensions   | <pre>{<br>  width: number,<br>  height: number<br>} | NO       | The dimensions of the image URL specified. If not set, the dimensions for all images are calculated before launch. <br><br> If you cannot specify image dimensions and have a large number of images, it is recommended to display a loading spinner until the app is launched. |
| thumbnailUrl | string                                              | YES      | Lower resolution image URL, used for rendering previews in the browser                                                                                                                                                                                                       |
| url          | string                                              | YES      | Full resolution image URL, used for printing                                                                                                                                                                                                                                 |
